<?php
{
  /**
   * @license    http://www.cecill.info/licences/Licence_CeCILL-B_V1-fr.html
   * @author     Francois Merciol <webmestre@parlenet.org>
   *
   * Plugin Chess: Manage chess game connections
   */
  if (!defined ('DOKU_INC'))
    define ('DOKU_INC', realpath (dirname (__FILE__).'/../../..').'/');

  global $conf;
  @require_once (DOKU_INC.'inc/init.php');

  @include "lib/xml.php";
  @include "lib/user.php";
  @include "lib/group.php";
  @include "lib/connection.php";

  if (strpos ($conf['savedir'], '/') === 0)
    $chessDir = $conf['savedir']."/chess/";
  else
    $chessDir = DOKU_INC.$conf['savedir']."/chess/";

  if (!is_dir ($chessDir))
    mkdir ($chessDir);

  global $userDBName, $userDB;
  global $groupDBName, $groupDB, $groupLoginDBIdx;
  global $connectionDir, $connectionPipeBase, $connectionExt, $connectionDB, $connectionLoginDBIdx, $OVH;

  $userDBName = $conf['savedir']."/chess/usersdb.php";
  $userDB = array ();

  $groupDBName = $conf['savedir']."/chess/groupsdb.php";
  $groupDB = array ();
  $groupLoginDBIdx = array ();

  $connectionDir = $conf['savedir']."/chess/connections";
  if (!is_dir ($connectionDir))
    mkdir ($connectionDir);
  $connectionPipeBase = "pipe-";
  $connectionExt = "php";
  $connectionDB = array ();
  $connectionLoginDBIdx = array ();
  $OVH = true;

  user::loadUsers ();
  group::loadGroups ();
  connection::loadConnections ();
}

// ============================================================
class chess {

  // ============================================================
  function login ($pearId, $firstPaquet) {
    xml::login ($pearId, $firstPaquet);
  }

  // ============================================================
  function readXML () {
    return xml::readXML ();
  }

  // ============================================================
  function broadcast ($pearId, $request, $firstPaquet) {
    xml::broadcast ($pearId, $request, $firstPaquet);
  }

  // ============================================================
  function receiveQueue ($pearId, $wait) {
    return connection::receiveQueue ($pearId, $wait);
  }

  // ============================================================
  function writeXML ($msg) {
    xml::writeXML ($msg);
  }

  // ============================================================
  function  completeForm () {
    if (!isset ($_REQUEST ['operation']))
      return;
    switch ($_REQUEST ['operation']) {

    case "addUser" :
      $message = user::addUser ($_REQUEST ['login'], $_REQUEST ['mel'], $_REQUEST ['passwd'], $_REQUEST ['passwd2']);
      break;
    case "removeUser" :
      $message = user::removeUser ($_REQUEST ['login']);
      break;

    case "createGroup" :
      $message = group::createGroup ($_REQUEST ['login'], $_REQUEST ['groupName']);
      break;
    case "removeGroup" :
      $message = group::removeGroup ($_REQUEST ['login'], $_REQUEST ['groupName']);
      break;
    case "addGroupAdmin" :
      $message = group::addGroupAdmin ($_REQUEST ['login'], $_REQUEST ['groupName'], $_REQUEST ['argument']);
      break;
    case "removeGroupAdmin" :
      $message = group::removeGroupAdmin ($_REQUEST ['login'], $_REQUEST ['groupName'], $_REQUEST ['argument']);
      break;
    case "addGroupMember" :
      $message = group::addGroupMember ($_REQUEST ['login'], $_REQUEST ['groupName'], $_REQUEST ['argument']);
      break;
    case "removeGroupMember" :
      $message = group::removeGroupMember ($_REQUEST ['login'], $_REQUEST ['groupName'], $_REQUEST ['argument']);
      break;

    case "joinGroup" :
      $message = connection::joinGroup ($_REQUEST ['pearId'], $_REQUEST ['groupName']);
      break;
    case "leftGroup" :
      $message = connection::leftGroup ($_REQUEST ['pearId']);
      break;
    case "connect" :
      $message = connection::connect ($_REQUEST ['pearId'], $_REQUEST ['login']);
      break;
    case "disconnect" :
      $message = connection::disconnect ($_REQUEST ['pearId']);
      break;
    case "removeUser" :
      $message = connection::removeUser ($_REQUEST ['login']);
      break;
    case "removeGroup" :
      $message = connection::removeGroup ($_REQUEST ['groupName']);
      break;
    case "removeConnexions" :
      $message = connection::removeConnexions ();
      break;
    }
  }

  // ============================================================
  function  printUserTab () {
    user::showUsers ();
  }

  // ============================================================
  function  printGroupTab () {
    group::showAllGroup ();
  }

  // ============================================================
  function  printConnectionTab () {
    connection::showConnections ();
  }

  // ============================================================
  function  printUserForm () {
    echo '
      <form method="post" action="">
      <table>
	<tr><td>utilisateur :</td><td><input type="text" name="login" value="'.$_REQUEST ['login'].'" /></td></tr>
	<tr><td>mel :</td><td><input type="text" name="mel" value="'.$_REQUEST ['mel'].'" /></td></tr>
	<tr><td>mot de passe :</td><td><input type="password" name="passwd" /></td></tr>
	<tr><td>confirmation :</td><td><input type="password" name="passwd2" /></td></tr>

	<tr><td>operation :</td><td><select name="operation" >
          <option value="addUser" />addUser</option>
          <option value="removeUser" />removeUser</option>
	<tr><td colspan="2"><input type="submit" name="action" value="validation" /></td></tr>
      </table>
      </form>';
  }

  // ============================================================
  function  printGroupForm () {
    echo '
      <form method="post" action="">
      <table>
	<tr><td>utilisateur :</td><td><input type="text" name="login" value="'.$_REQUEST ['login'].'" /></td></tr>
	<tr><td>groupe :</td><td><input type="text" name="groupName" value="'.$_REQUEST ['groupName'].'" /></td></tr>
	<tr><td>argument :</td><td><input type="text" name="argument" value="'.$_REQUEST ['argument'].'" /></td></tr>

	<tr><td>operation :</td><td><select name="operation" >
          <option value="createGroup" />createGroup</option>
          <option value="removeGroup" />removeGroup</option>
          <option value="addGroupAdmin" />addGroupAdmin</option>
          <option value="removeGroupAdmin" />removeGroupAdmin</option>
          <option value="addGroupMember" />addGroupMember</option>
          <option value="removeGroupMember" />removeGroupMember</option>
        </select></td></tr>

	<tr><td colspan="2" ><input type="submit" name="action" value="validation" /></td></tr>
      </table>
      </form>';
  }

  // ============================================================
  function  printConnectionForm () {
    echo '
      <form method="post" action="" >
      <table>
	<tr><td>pearId :</td><td><input type="text" name="pearId" value="'.$_REQUEST ['pearId'].'" /></td></tr>
	<tr><td>groupName :</td><td><input type="text" name="groupName" value="'.$_REQUEST ['groupName'].'" /></td></tr>
	<tr><td>login :</td><td><input type="text" name="login" value="'.$_REQUEST ['login'].'" /></td></tr>

	<tr><td>operation :</td><td><select name="operation" >
          <option value="joinGroup" />joinGroup</option>
          <option value="leftGroup" />leftGroup</option>
          <option value="connect" />connect</option>
          <option value="disconnect" />disconnect</option>
          <option value="removeUser" />removeUser</option>
          <option value="removeGroup" />removeGroup</option>
          <option value="removeConnexions" />removeConnexions</option>

        </select></td></tr>
	<tr><td colspan="2" ><input type="submit" name="action" value="validation" /></td></tr>
      </table>
      </form>';
  }

  // ============================================================
}
